==> bibletime-trinity-3.5.13.2.tar.xz: bibletime-trinity-3.5.13.2/bibletime/frontend/searchdialog/csearchresultview.h <==
/*********
*
* This file is part of BibleTime's source code, http://www.bibletime.info/.
*
* Copyright 1999-2006 by the BibleTime developers.
* The BibleTime source code is licensed under the GNU General Public License version 2.0.
*
**********/



#ifndef CSEARCHRESULTSVIEW_H
#define CSEARCHRESULTSVIEW_H

//BibleTime includes
#include "backend/cswordmoduleinfo.h"

//KDE includes
#include <klistview.h>

//forward declarations
class TQLabel;
class TQCheckBox;
class TQPushButton;
class TQRadioButton;

class KComboBox;
class KActionMenu;
class KAction;
class KHistoryCombo;
class KProgress;
class KPopupMenu;

class CReadDisplay;

namespace Search {
	namespace Result {

class CSearchResultView  : public KListView {
	Q_OBJECT
  TQ_OBJECT
public:
	CSearchResultView(TQWidget* parent, const char* name = 0);
	virtual ~CSearchResultView();
	/** Returns the module which is currently used. */
	CSwordModuleInfo* const module();

protected: // Protected methods
	/**
	* Initializes the view of this widget.
	*/
	void initView();
	void initConnections();
	virtual TQDragObject* dragObject();

public slots: // Public slots
	void saveItems();
	/**
	* Setups the list with the given module.
	*/
	void setupTree(CSwordModuleInfo*);
   void setupStrongsTree(CSwordModuleInfo*, TQStringList*);
	void copyItemsWithText();
	void copyItems();
	void saveItemsWithText();
	/**
	* Reimplementation to show the popup menu.
	*/
	virtual void showPopup(KListView*, TQListViewItem* i, const TQPoint& point);

protected slots: // Protected slots
	void printItems();
	/**
	* Is connected to the signal executed, which is emitted when a mew item was chosen.
	*/
	void executed(TQListViewItem*);

private:
	struct {
		KActionMenu* saveMenu;
		struct {
			KAction* result;
			KAction* resultWithText;
		}
		save;

		KActionMenu* printMenu;
		struct {
			KAction* result;
		}
		print;

		KActionMenu* copyMenu;
		struct {
			KAction* result;
			KAction* resultWithText;
		}
		copy;
	}
	m_actions;
	
	KPopupMenu* m_popup;
	CSwordModuleInfo* m_module;

signals: // Signals
	void keySelected(const TQString&);
};

	} //end of namespace Result
} //end of namespace Search

#endif

==> bibletime-trinity-14.0.13.tar.xz: bibletime-trinity-14.0.13/bibletime/frontend/searchdialog/csearchresultview.h <==
/*********
*
* This file is part of BibleTime's source code, http://www.bibletime.info/.
*
* Copyright 1999-2006 by the BibleTime developers.
* The BibleTime source code is licensed under the GNU General Public License version 2.0.
*
**********/



#ifndef CSEARCHRESULTSVIEW_H
#define CSEARCHRESULTSVIEW_H

//BibleTime includes
#include "backend/cswordmoduleinfo.h"

//KDE includes
#include <tdelistview.h>

//forward declarations
class TQLabel;
class TQCheckBox;
class TQPushButton;
class TQRadioButton;

class KComboBox;
class TDEActionMenu;
class TDEAction;
class KHistoryCombo;
class KProgress;
class TDEPopupMenu;

class CReadDisplay;

namespace Search {
	namespace Result {

class CSearchResultView  : public TDEListView {
	Q_OBJECT
  
public:
	CSearchResultView(TQWidget* parent, const char* name = 0);
	virtual ~CSearchResultView();
	/** Returns the module which is currently used. */
	CSwordModuleInfo* const module();

protected: // Protected methods
	/**
	* Initializes the view of this widget.
	*/
	void initView();
	void initConnections();
	virtual TQDragObject* dragObject();

public slots: // Public slots
	void saveItems();
	/**
	* Setups the list with the given module.
	*/
	void setupTree(CSwordModuleInfo*);
   void setupStrongsTree(CSwordModuleInfo*, TQStringList*);
	void copyItemsWithText();
	void copyItems();
	void saveItemsWithText();
	/**
	* Reimplementation to show the popup menu.
	*/
	virtual void showPopup(TDEListView*, TQListViewItem* i, const TQPoint& point);

protected slots: // Protected slots
	void printItems();
	/**
	* Is connected to the signal executed, which is emitted when a mew item was chosen.
	*/
	void executed(TQListViewItem*);

private:
	struct {
		TDEActionMenu* saveMenu;
		struct {
			TDEAction* result;
			TDEAction* resultWithText;
		}
		save;

		TDEActionMenu* printMenu;
		struct {
			TDEAction* result;
		}
		print;

		TDEActionMenu* copyMenu;
		struct {
			TDEAction* result;
			TDEAction* resultWithText;
		}
		copy;
	}
	m_actions;
	
	TDEPopupMenu* m_popup;
	CSwordModuleInfo* m_module;

signals: // Signals
	void keySelected(const TQString&);
};

	} //end of namespace Result
} //end of namespace Search

#endif
